==> igniteui-react-core-16.16.1.tgz: package/esm5/lib/ProvideCalculatorEventArgsDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { ProvideCalculatorEventArgsDescription } from "./ProvideCalculatorEventArgsDescription";
/**
 * @hidden
 */
var ProvideCalculatorEventArgsDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(ProvideCalculatorEventArgsDescriptionMetadata, _super);
    function ProvideCalculatorEventArgsDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    ProvideCalculatorEventArgsDescriptionMetadata.b = function (a) {
        if (ProvideCalculatorEventArgsDescriptionMetadata.a == null) {
            ProvideCalculatorEventArgsDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            ProvideCalculatorEventArgsDescriptionMetadata.c(ProvideCalculatorEventArgsDescriptionMetadata.a);
        }
        if (a.g(ProvideCalculatorEventArgsDescriptionMetadata.a)) {
            return;
        }
        a.s(ProvideCalculatorEventArgsDescriptionMetadata.a);
    };
    ProvideCalculatorEventArgsDescriptionMetadata.c = function (a) {
    };
    ProvideCalculatorEventArgsDescriptionMetadata.d = function (a) {
        ProvideCalculatorEventArgsDescriptionMetadata.b(a);
        a.u("ProvideCalculatorEventArgs", function () { return new ProvideCalculatorEventArgsDescription(); });
        a.t("ProvideCalculatorEventArgs", ProvideCalculatorEventArgsDescriptionMetadata.a);
    };
    ProvideCalculatorEventArgsDescriptionMetadata.$t = markType(ProvideCalculatorEventArgsDescriptionMetadata, 'ProvideCalculatorEventArgsDescriptionMetadata');
    ProvideCalculatorEventArgsDescriptionMetadata.a = null;
    return ProvideCalculatorEventArgsDescriptionMetadata;
}(Base));
export { ProvideCalculatorEventArgsDescriptionMetadata };

==> igniteui-react-core-18.1.2.tgz: package/esm5/lib/ProvideCalculatorEventArgsDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { ProvideCalculatorEventArgsDescription } from "./ProvideCalculatorEventArgsDescription";
/**
 * @hidden
 */
var ProvideCalculatorEventArgsDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(ProvideCalculatorEventArgsDescriptionMetadata, _super);
    function ProvideCalculatorEventArgsDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    ProvideCalculatorEventArgsDescriptionMetadata.b = function (a) {
        if (ProvideCalculatorEventArgsDescriptionMetadata.a == null) {
            ProvideCalculatorEventArgsDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            ProvideCalculatorEventArgsDescriptionMetadata.c(ProvideCalculatorEventArgsDescriptionMetadata.a);
        }
        if (a.j(ProvideCalculatorEventArgsDescriptionMetadata.a)) {
            return;
        }
        a.y(ProvideCalculatorEventArgsDescriptionMetadata.a);
    };
    ProvideCalculatorEventArgsDescriptionMetadata.c = function (a) {
    };
    ProvideCalculatorEventArgsDescriptionMetadata.d = function (a) {
        ProvideCalculatorEventArgsDescriptionMetadata.b(a);
        a.aa("ProvideCalculatorEventArgs", function () { return new ProvideCalculatorEventArgsDescription(); });
        a.z("ProvideCalculatorEventArgs", ProvideCalculatorEventArgsDescriptionMetadata.a);
    };
    ProvideCalculatorEventArgsDescriptionMetadata.$t = markType(ProvideCalculatorEventArgsDescriptionMetadata, 'ProvideCalculatorEventArgsDescriptionMetadata');
    ProvideCalculatorEventArgsDescriptionMetadata.a = null;
    return ProvideCalculatorEventArgsDescriptionMetadata;
}(Base));
export { ProvideCalculatorEventArgsDescriptionMetadata };
